CivitaModelVersionImage class

Constructors

CivitaModelVersionImage.fromJson(Map<String, dynamic> json)

Properties

hash String
The blurhash of the image
latefinal
hashCode int
The hash code for this object.
no setterinherited
hasMeta bool
Whether or not the image has metadata
latefinal
height int
The height of the image
latefinal
id int?
The id of the image
getter/setter pair
nsfwLevel int
The NSFW level of the image
latefinal
onSite bool
Whether or not the image is on civitai
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of image
latefinal
url String
The url of the image at it's source resolution
latefinal
width int
The width of the image
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited