CivitaModelVersion class
Constructors
-
CivitaModelVersion.fromJson(Map<
String, dynamic> json)
Properties
- availability ↔ String
-
The availability of the model version
latefinal
- baseModel ↔ String
-
The base model used to train the model
latefinal
- baseModelType ↔ String
-
The type of base model
latefinal
- createdAt ↔ String
-
The date in which the version was created
latefinal
- description ↔ String
-
The description of the model version (usually a changelog)
latefinal
- downloadUrl ↔ String
-
The download url to get the model file for this specific version
latefinal
-
files
↔ List<
CivitaFile> -
The files associated with this model version
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int
-
The identifier for the model version
latefinal
-
images
↔ List<
CivitaModelVersionImage> -
The images associated with this model version
latefinal
- index ↔ int?
-
The index of the model version
getter/setter pair
- name ↔ String
-
The name of the model version
latefinal
- nsfwLevel ↔ int
-
The NSFW level of the model version
latefinal
- publishedAt ↔ String
-
The date the model was published
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
trainedWords
↔ List<
String> -
The words used to trigger the model
latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited