CivitaStats class
Constructors
-
CivitaStats.fromJson(Map<
String, dynamic> json)
Properties
- commentCount ↔ int
-
The number of comment reactions
latefinal
- cryCount ↔ int
-
The number of cry reactions
latefinal
- downloadCount ↔ int
-
The number of downloads the model has
latefinal
- favoriteCount ↔ int
-
The number of favorites the model has
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- heartCount ↔ int
-
The number of heart reactions
latefinal
- laughCount ↔ int
-
The number of laugh reactions
latefinal
- likeCount ↔ int
-
The number of like reactions
latefinal
- rating ↔ double
-
The average rating of the model
latefinal
- ratingCount ↔ int
-
The number of ratings the model has
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbsDownCount ↔ int
-
The number of thumbs down
latefinal
- thumbsUpCount ↔ int
-
The number of thumbs up
latefinal
- tippedAmountCount ↔ int
-
The amount of money tipped
latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited